@@ -89,10 +89,10 @@ bool Pty::writeCmd(QString* message, QString* response, int msecTimeout, QString
           //perror("read");
           break;
         }
+
         if (response){
-            for (int i = 0; i < nread; i++) {
+            for (int i = 0; i < nread; i++)
                 response->append(buf[i]);
-            }
 #ifdef DEBUG
             printf(buf);
 #endif
