@@ -89,6 +89,7 @@ void SmsSender::printUsage()
     consoleOutput("               144 - 167 12 Hours + ((VP-143) x 30 mins)");
     consoleOutput("               168 - 196 (VP-166) x 1 day");
     consoleOutput("               197 - 255 (VP-192) x 1 week");
+    consoleOutput("  -p PIN     : pin code (for pin locked SIM)");
 }
 
 int SmsSender::exec()
@@ -128,6 +129,8 @@ int SmsSender::exec()
                 m_DeliveryReport = true;*/
             else if (param == "-v")
                 currArg = SmsSender::argValidity;
+            else if(param == "-p")
+                currArg = SmsSender::argPin;
             else{
                 consoleOutput(QString("ERR: unrecognized argument: %1").arg(param));
                 return errArguments;
@@ -164,11 +167,14 @@ int SmsSender::exec()
                         bool ok = false;
                         m_Validity = param.toInt(&ok);
                         if (!ok || m_Validity < 0 || m_Validity > 255){
-                            consoleOutput(QString("WARNING: Invalid validity period %1").arg(m_Validity));
+                            consoleOutput(QString("WARNING: Invalid validity period %1, switching to default value").arg(m_Validity));
                             m_Validity = 167;
                         }
                     }
                     break;
+                case SmsSender::argPin:
+                    m_Pin = param;
+                    break;
                 default:
                     break;
             }
@@ -284,7 +290,14 @@ bool SmsSender::send(QString number, QString messageText)
         consoleOutput(".", false);
     }
 
-    //AT+CPIN="0000" <-- TODO: send if the SIM is pin-protected
+    if (res && !m_Pin.isEmpty()){
+        if (!writeCmd(pty, QString("AT+CPIN=\"%1\"\r").arg(m_Pin), "OK")){
+            consoleOutput(QString("\nERR: Failed to send at+cpin command"));
+            res = false;
+        }else
+            consoleOutput(".", false);
+    }
+
     if (res){
         if (!writeCmd(pty, "AT+CMGF=1\r", "OK")){
             consoleOutput(QString("\nERR: Failed to send at+cmgf command"));
@@ -318,7 +331,7 @@ bool SmsSender::send(QString number, QString messageText)
     }
 
     if (res){
-        if (!writeCmd(pty, messageText, messageText)){
+        if (!writeCmd(pty, messageText, messageText.trimmed(), 1000)){
             consoleOutput(QString("\nERR: Failed to send text message"));
             res = false;
         }else
