@@ -47,6 +47,7 @@ private:
         argFlash,
         argDeliveryReport,
         argValidity,
+        argPin,
     };
 
     enum errors{
@@ -66,6 +67,7 @@ private:
     //bool m_DeliveryReport;
     int m_Validity;
     QFile* m_LogFile;
+    QString m_Pin;
 
     void consoleOutput(QString output, bool newline=true);
     void printInfo();
